@@ -23,7 +23,7 @@ import optuna.integration.lightgbm
 from ._common import logger
 
 
-__version__ = "0.13.0"
+__version__ = "0.13.1"
 _T1 = TypeVar("_T1")
 
 _CachedCallableV1_CACHE_V1 = dict()
@@ -127,30 +127,21 @@ def train_lightgbm_v1(
     kwargs: Mapping[str, Any],
     params_hpo: Mapping[str, Any],
     kwargs_hpo: Mapping[str, Any],
+    study: Optional[optuna.study.Study],
 ) -> Dict[str, Any]:
-    params_best: Dict[str, Any] = dict()
-    tuning_history: List[Any] = []
     with timing_v1("Run optuna.integration.lightgbm.train: %s", logger.debug):
         model_hpo = optuna.integration.lightgbm.train(
-            params_hpo,
-            data_train,
-            valid_sets=data_val,
-            best_params=params_best,
-            tuning_history=tuning_history,
-            **kwargs_hpo,
+            params_hpo, data_train, valid_sets=data_val, study=study, **kwargs_hpo,
         )
+    params_best = model_hpo.get_best_booster().params
     logger.debug("model_hpo.best_score %s", model_hpo.best_score)
     logger.debug("params_best %s", params_best)
+
     params_fine = {**params_best, **params}
     logger.debug("params_fine %s", params_fine)
     with timing_v1("Run lgb.train: %s", logger.debug):
         model_fine = lgb.train(params_fine, data_train, valid_sets=data_val, **kwargs)
-    return dict(
-        model=model_fine,
-        params=params_fine,
-        params_best=params_best,
-        tuning_history=tuning_history,
-    )
+    return dict(model=model_fine, params=params_fine, params_best=params_best,)
 
 
 def intersect1d_v1(xss: Sequence[Sequence[_T1]], assume_unique=False) -> Sequence[_T1]:
